@@ -8,13 +8,13 @@ MapCell<-function(data, Area="World", minLon, maxLon, minLat, maxLat,
   font.lab = 1, font.axis = 1, lwdP=0.6, lwdC=0.1, trans=c(1,1), log=c(0,0),
   ndigits=0, ini=NULL, end=NULL, jpg=FALSE, filejpg="Map.jpg"){
 
-if(class(data)=="data.frame"){
+if(inherits(data, "data.frame")){
 data<-as.matrix(data)
 }
 
 colscale<-append("transparent",colscale)
 
-if(class(data)=="RasterLayer"){
+if(inherits(data, "RasterLayer")){
 
 if(round(raster::xmin(data))==-180 & round(raster::ymin(data))==-90 & round(raster::xmax(data))==180 & round(raster::ymax(data))==90){
 m1<-raster::as.matrix(data)
